;(function($, window, document, undefined) {

    Drupal.behaviors.keyboardShortcuts = {
        attach: function (context, settings) {
            if (context === document) {
                for (index in settings.keyboard_shortcuts.shortcuts) {
                    var shortcut = settings.keyboard_shortcuts.shortcuts[index];
                    var keystrokes = $.map(shortcut.keystroke.split(/[,]+/), $.trim);

                    var action = shortcut.action;
                    var prevent_default = shortcut.prevent_default;

                    switch(action){
                        case 'trigger':

                            Mousetrap.bind(keystrokes, (function(selector, type, prevent_default) {
                                return function (e, combo) {
                                    $(selector).trigger(type);
                                    return !prevent_default;
                                };
                            })(shortcut.arguments.selector, shortcut.arguments.type, prevent_default));

                            break;

                        case 'modal':

                            Mousetrap.bind(keystrokes, (function(url, prevent_default) {
                                return function (e, combo) {

                                    var ajaxSettings = {
                                        url: url,
                                        dialogType: 'modal',
                                        dialog: { width: 400 },
                                    };
                                    var myAjaxObject = Drupal.ajax(ajaxSettings);
                                    myAjaxObject.execute();

                                    return !prevent_default;
                                };
                            })(shortcut.arguments.url, prevent_default));

                            break;

                        case 'redirect':

                            Mousetrap.bind(keystrokes, (function(url, prevent_default) {
                                return function (e, combo) {
                                    window.location = url;
                                    return !prevent_default;
                                };
                            })(shortcut.arguments.url, prevent_default));

                            break;

                        case 'callback':

                            Mousetrap.bind(keystrokes, (function(callback_function, prevent_default){
                                return function (e, combo) {
                                    prevent_default &= window[callback_function](e, combo);
                                    return !prevent_default;
                                };
                            })(shortcut.arguments.callback, prevent_default));

                            break;
                    }

                }

                Mousetrap['stopCallback'] = function(e, element, combo) {
                    // If the element has the class "mousetrap" then no need to stop.
                    if ((' ' + element.className + ' ').indexOf(' mousetrap ') > -1) {
                        return false;
                    }

                    for (index in settings.keyboard_shortcuts.shortcuts) {
                        var shortcut = settings.keyboard_shortcuts.shortcuts[index];
                        var keystrokes = shortcut.keystroke.split(/[\s,]+/);
                        for(s in keystrokes){
                            if(combo===keystrokes[s] && shortcut.enable_during_input){
                                return false;
                            }
                        }
                    }

                    // Stop for input, select, and textarea.
                    return element.tagName === 'INPUT' || element.tagName === 'SELECT' || element.tagName === 'TEXTAREA' || (element.contentEditable && element.contentEditable === 'true');
                };
            }
        },

    };

})(jQuery, window, document);
